海蒂和爷爷 (豆瓣)
Description: 海蒂和爷爷电影简介和剧情介绍,海蒂和爷爷影评、图片、预告片、影讯、论坛、在线购票
Keywords: 海蒂和爷爷,Heidi,海蒂和爷爷影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.48豆瓣电影Top250

# 海蒂和爷爷 Heidi (2015)

导演: 阿兰·葛斯彭纳
编剧: 约翰娜·施皮里 / 佩特拉·比翁迪娜·沃尔普
主演: 阿努克·斯特芬 / 布鲁诺·冈茨 / 昆林·艾格匹 / 安娜·申茨 / 伊莎贝尔·奥特曼 / 莉莲·奈福 / 彼得·杰克林 / 克里斯托夫·高格勒 / 丽贝卡·因德穆 / 莫妮卡·古布瑟 / 阿瑟·比勒 / 玛丽埃塔·耶米 / 彼得·洛迈尔 / 卡塔琳娜·舒特勒 / 杰拉·哈斯 / 迈克尔·克兰茨 / 劳拉·帕克 / 马库斯·赫林 / 马克西姆·梅米特 / 汉娜洛蕾·赫格
类型: 剧情 / 家庭 / 冒险
官方网站: www.zodiacpictures.com/de/projekte/heidi
制片国家/地区: 德国 / 瑞士
语言: 南非语 / 德语 / 瑞士德语
上映日期: 2019-05-16(中国大陆) / 2015-12-10(德国)
片长: 111分钟
又名: 飘零燕(港) / 海蒂 / 阿尔卑斯山少女海蒂
IMDb: tt3700392
豆瓣评分
引用
9.3
546793人评价
5星
69.2%
4星
26.0%
3星
4.4%
2星
0.3%
1星
0.1%
好于 99% 家庭片
好于 99% 剧情片
想看 看过
评价:
推荐

## 海蒂和爷爷的剧情简介 · · · · · ·

孤儿海蒂（阿努克·斯特芬 饰）被姨母迪蒂（安娜·希恩斯 饰）送上了阿尔卑斯山，与远离小镇独居于高山的祖父（布鲁诺·甘茨 饰）一同生活。活泼的海蒂在这里如鱼得水，不仅收获了羊倌彼得（奎林·阿格里皮 饰）的友情和孤僻祖父的亲情，还与山下彼得的家人打成一片。一天，海蒂同彼得在山上放羊，姨母突然出现，连哄带骗将海蒂卖到法兰克福的泽塞曼家。从此，目不识A的海蒂成为了小姐克拉拉（伊莎贝尔·奥特曼 饰）的伴读。克拉拉幼年丧母，大病一场再不能站立，只能被困在豪宅中与轮椅相伴。父亲（马克西姆·梅米特 饰）常年在外很少回家，寂寞的克拉拉把海蒂当成了救命稻草。海蒂能适应泽塞曼家的新生活吗？远在天边的祖父和彼得还能再见吗？克拉拉的腿还有好起来的希望吗？ ©豆瓣

## 海蒂和爷爷的演职员 · · · · · · ( 全部 23 )

- 阿兰·葛斯彭纳 导演
- 阿努克·斯特芬 饰 海蒂 Heidi
- 布鲁诺·冈茨 饰 爷爷 Alpöhi
- 昆林·艾格匹 饰 彼得 Geissenpeter
- 安娜·申茨 饰 姨妈 Dete
- 伊莎贝尔·奥特曼 饰 克拉拉 Klara

## 海蒂和爷爷的视频和图片 · · · · · · ( 预告片8 | 视频评论1 · 添加 | 图片904 · 添加 )

## 海蒂和爷爷的获奖情况 · · · · · · ( 全部 )

- 第3届豆瓣电影年度榜单
- 年度冷门佳片

## 喜欢这部电影的人也喜欢 · · · · · ·

  饮食男女

  步履不停

  寻梦环游记

  小偷家族

  海街日记

  何以为家

  我是山姆

  普罗旺斯的夏天

  海边的曼彻斯特

  天才少女

我要写短评

## 海蒂和爷爷的短评 · · · · · · ( 全部 168789 条 )

热门 / 最新 / 好友

### 5884 有用 怂囧小赫 看过 2016-09-14 20:22:29

人至善，景至美，故事细腻，淳朴动人，人生本该如此，温情永存，何惧苦难？

### 2468 有用 yolanta 看过 2016-08-04 13:39:05

有生之年不去瑞士还有啥可活？

### 3315 有用 Ck 看过 2016-06-27 17:48:41

人老了，由頭哭到尾。

### 4612 有用 左佐 看过 2016-08-31 12:54:35

成功之处在于每个角色都很立体，都有优点缺点，海蒂不守规矩却天真可爱，克劳拉自私骄纵却优雅美丽，皮特淘气却耿直，爷爷脾气古怪却默默付出，女管家严厉却谨慎。山里的人没有那么朴实无华，“宫殿”里的人也没那么惟利是图。

### 2168 有用 私~川流 看过 2016-07-15 19:35:00

这是一部被翻拍多次的剧本。小的时候看过秀兰邓波的版本，只记得阿尔卑斯的山景。不知为何，看过这部电影，仿佛回到了上个世纪，简单地剧本，没有特效，专注于人物的情感与内心。这才是艺术真正动人的地方。

> 更多短评 168789条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 海蒂和爷爷的影评 · · · · · · ( 全部 2402 条 )

热门 / 最新 / 好友
Haidi 2016-07-04 10:36:22

## 像Heidi一般去善良并真诚面对人生每一个糟糕的环境，为自己。

“大家都笑我，因为我想写故事” “那是因为大家知道的太少，而你看过更大的世界。如果你觉得这个世界有那些东西会让你快乐，就去做，无论别人说什么” 老奶奶和小Heidi的对话让我不断反思当下的社会，当你想要追随自己内心的声音，总是能听到一些质疑，不俏甚至是讥笑，然后我... (展开)
2602 71 145回应 收起
克洛伊的小镇 2016-08-24 13:22:52

## 回到最初的仙境

这篇影评可能有剧透

很久很久，没有一部电影担得起心旷神怡这四个字的评价了。 几个月以来，我一直因为没有找到合适的电影素材而一度中断了影评的更新。中间还出了几部游戏评测来撑撑场面，作为过渡。有的时候我也怀疑过是不是我对电影的表达欲已经耗尽了，对于一部新作却不能产生新的感触。直到昨... (展开)
2606 48 194回应 收起
Ainsane 2016-08-18 09:41:44

## 长大以后才读懂的童话

这篇影评可能有剧透

《海蒂》这本书是我小时候非常爱读的，那时候喜欢只是因为向往书中描写的人间仙境般的阿尔卑斯山风景和充满趣味性的情节。这样一个天真活泼，不用上学，每天漫山乱跑的女孩的生活与我的相差甚远，我觉得美好得像个童话。 现在距我第一次读这本书已经过去了至少十年，我再看这部... (展开)
948 22 76回应 收起
当啷当啷叮 2017-03-26 01:47:10

## 不是心目中的海蒂

删掉了很多情节，这点也有理解，电影时间紧凑，自然不能一一表现原著。但是连爷爷和海蒂的人设都改了，也有点过分。 海蒂在原著里是一个真正有感染力的小姑娘，她从来没害怕过爷爷，如果是原著的海蒂，肯定会当场反驳皮特，然后直接去问爷爷有没有杀过人。 爷爷在原著里分明是... (展开)
312 77 187回应 收起
狐狐_狸狸 2016-08-10 23:06:48

## 阿尔卑斯山少女

又见阿尔卑斯山，大自然用最鲜亮的色彩描绘的地方，蓝褐色的山脊上披着绿色的杉树，连坡的青草里各色野花和蝴蝶嬉戏，长着弯角的黑白两色山羊游移其中，纯净的湖水和白云对话，高高的雪山顶仰望着蓝天的笑脸，半山中的两座木屋在季节里与绿草和大雪相伴。还有清脆的羊铃，和羊... (展开)
235 16 4回应 收起
一棵海椒 2016-08-29 15:26:28

## 经典不朽

《海蒂》是瑞士著名儿童文学作家约翰娜·斯比丽创作于十九世纪末的文学巨作，作品问世一百多年来多次被搬上银幕，是儿童文学史上的经典。让人记忆深刻的影视改编有1937年秀兰邓波儿版电影，1974年高畑勋和宫崎骏版动画连续剧和1993年迪士尼电视电影。每个版本都让《海蒂》... (展开)
131 5 11回应 收起
关关 2016-07-10 20:56:56

## 小小精灵——海蒂

这篇影评可能有剧透

今天是第一次写影评，因为忽然发现想不起来同样是自己喜欢的孩子和老人题材的电影的名字了（后来想起是“孙子从美国来”）。于是决定记录下每一部对自己有触动的电影，毕竟，人生不就是因为这些让我们感动的时刻才有意义么？ 从海蒂第一次来时爷爷对海蒂的排斥，到渐渐接受喜欢... (展开)
158 9 18回应 收起
子戈 2019-05-20 11:18:54 #关于《海蒂和爷爷》的看点汇总

## 谁也不是天生的歌颂者

周五一大早，跑去影院看《海蒂和爷爷》，由于堵车，转为骑行，到影院时已经大汗淋漓。落座后，影片开始了。第一个镜头就是阿尔卑斯山沁人的景色，瞬间收掉一身黏汗，惬意起来。 要么说观影心态很重要呢。看电影就像谈恋爱，对的片、对的时间缺一不可。 现在豆瓣上的评分，《海... (展开)
157 3 17回应 收起
Seven姐 2016-11-11 11:46:54

## 生命真的可以如此单纯和美好

这篇影评可能有剧透

很偶然的机会，看了电影《海蒂和爷爷》。 我本来没有报多大期待的，前十分钟还在盘着双腿啃泡椒鸡爪。但是电影的画面实在太美了，随手一截，就是一幅画。慢慢的，我被带入到电影当中。电影节奏很缓慢，简简单单的几句话，便让人倍感温暖。 海蒂是不幸的：父母早逝，被阿姨带... (展开)
143 3 5回应 收起
是不想上班的鱼 2016-08-27 20:56:27

## 还记得你的童年吗

这篇影评可能有剧透

故事里海蒂从小跟着姨妈一起生活，后来姨妈把她送到了阿尔卑斯山的爷爷那里，爷爷是个脾气古怪但却很善良和蔼的老头，开始时他想把海蒂送给牧师，可相处了一段时间后他的心因为海蒂变得柔软起来，他喜欢上了这个乖巧可爱的小姑娘，他规定海蒂每天放羊前必须喝一大碗羊奶，他让... (展开)
61 4 7回应 收起

> 更多影评 2402篇

添加新讨论

## 讨论区 · · · · · ·

这个电影是国内和国外评分悬殊最大的电影 | 来自西瓜菠萝影视 | 30 回应 | 2022-11-24 09:38:57
说实话，我也不觉得这片值9.2分。。。 | 来自黑娃儿 | 51 回应 | 2022-11-23 21:09:43
爱 | 来自南华老仙 |  | 2022-11-17 23:10:32
海蒂与爷爷取景地点是哪里啊？ | 来自已注销 | 3 回应 | 2022-11-09 14:05:11
海蒂的爷爷好孤独，等他干不动了要怎么办呢？好可怜啊 | 来自zjd37382822 |  | 2022-11-06 20:20:07

> 去这部影片的讨论区（全部465条）

## 关于《海蒂和爷爷》的问题 · · · · · · ( 全部33个 )

- 背景是什么时代的，剧中人物好像都信奉基督教？ 4人回答
- 元首演的是哪个角色？ 5人回答

> 全部33个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 优酷视频 VIP免费观看
- 芒果TV VIP免费观看
- 哔哩哔哩 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【容易忽视的好电影】 (影志)
- 关于德国 你该看的 (≌菩提风花)
- 豆瓣电影【口碑榜】2022-06-13 更新 (影志)
- 看片识女人 (phoebe)

## 谁在看这部电影 · · · · · ·

- Melody
  刚刚 看过
- JANE -
  1分钟前 看过
- 戒
  2分钟前 看过

840679人看过 / 395836人想看

订阅海蒂和爷爷的评论:
feed: rss 2.0